@@ -12,12 +12,12 @@ use Data::Object::Class;
 
 extends 'Zing::PubSub';
 
-our $VERSION = '0.23'; # VERSION
+our $VERSION = '0.24'; # VERSION
 
 # BUILDERS
 
 fun BUILD($self) {
-  $self->{position} = $self->size;
+  $self->{position} = $self->size if !$self->isa('Zing::Table');
 
   return $self;
 }
