@@ -14,7 +14,7 @@ use Data::Object::ClassHas;
 use Cwd ();
 use Sys::Hostname ();
 
-our $VERSION = '0.23'; # VERSION
+our $VERSION = '0.24'; # VERSION
 
 # ATTRIBUTES
 
@@ -137,6 +137,16 @@ fun new_target($self) {
   $ENV{ZING_TARGET}
 }
 
+has system => (
+  is => 'ro',
+  isa => 'Name',
+  new => 1,
+);
+
+fun new_system($self) {
+  'zing'
+}
+
 1;
 
 =encoding utf8
@@ -262,6 +272,14 @@ This attribute is read-only, accepts C<(Maybe[Str])> values, and is optional.
 
 =cut
 
+=head2 system
+
+  system(Name)
+
+This attribute is read-only, accepts C<(Name)> values, and is optional.
+
+=cut
+
 =head2 target
 
   target(Maybe[Name])
