@@ -18,7 +18,7 @@ use Scalar::Util ();
 
 use overload '""' => 'string';
 
-our $VERSION = '0.23'; # VERSION
+our $VERSION = '0.24'; # VERSION
 
 # ATTRIBUTES
 
@@ -67,6 +67,7 @@ state $symbols = {
   'Zing::PubSub'   => 'pubsub',
   'Zing::Queue'    => 'queue',
   'Zing::Repo'     => 'repo',
+  'Zing::Table'    => 'table',
 };
 
 fun BUILDARGS($self, $item, @data) {
@@ -85,6 +86,10 @@ fun BUILDARGS($self, $item, @data) {
       $args->{symbol} = $symbols->{'Zing::Domain'};
       $args->{bucket} = $item->name;
     }
+    elsif ($item->isa('Zing::Table')) {
+      $args->{symbol} = $symbols->{'Zing::Table'};
+      $args->{bucket} = $item->name;
+    }
     elsif ($item->isa('Zing::Channel')) {
       $args->{symbol} = $symbols->{'Zing::Channel'};
       $args->{bucket} = $item->name;
@@ -126,7 +131,7 @@ fun BUILDARGS($self, $item, @data) {
     }
     $args->{target} = ($item->env->target || 'global');
     $args->{handle} = ($item->env->handle || 'main');
-    $args->{system} = 'zing';
+    $args->{system} = ($item->env->system || 'zing');
   }
   elsif(defined $item && !ref $item) {
     my $schema = [split /:/, "$item", 5];
@@ -137,9 +142,6 @@ fun BUILDARGS($self, $item, @data) {
     my $symbol = $schema->[3];
     my $bucket = $schema->[4];
 
-    unless ($system eq 'zing') {
-      $self->throw(error_term_unknow_system("$item"));
-    }
     unless (grep {$_ eq $symbol} values %$symbols) {
       $self->throw(error_term_unknow_symbol("$item"));
     }
@@ -281,6 +283,14 @@ method string() {
   return lc join ':', $system, $handle, $target, $symbol, $bucket;
 }
 
+method table() {
+  unless ($self->symbol eq 'table') {
+    $self->throw(error_term_invalid('table'));
+  }
+
+  return $self->string;
+}
+
 # ERRORS
 
 fun error_term_invalid(Str $name) {
@@ -303,11 +313,6 @@ fun error_term_unknow_symbol(Str $term) {
   message => qq(Error in term: Unrecognizable "symbol" in: $term),
 }
 
-fun error_term_unknow_system(Str $term) {
-  code => 'error_term_unknow_system',
-  message => qq(Error in term: Unrecognizable "system" in: $term),
-}
-
 1;
 
 =encoding utf8
