@@ -1,18 +1,11 @@
-package Redis;
-
-# safety measure
-unless ($ENV{TEST_REDIS}) {
-  *{"Redis::new"} = $INC{'Redis.pm'} = sub {
-    require Carp;
-    Carp::croak "Redis disabaled while testing"; undef
-  };
-}
-
 package Test::Zing;
 
 BEGIN {
-  $ENV{ZING_HOST} = '0.0.0.0';
-  $ENV{ZING_STORE} = 'Test::Zing::Store';
+  $ENV{ZING_HANDLE}  = 'main';
+  $ENV{ZING_HOST}    = '0.0.0.0';
+  $ENV{ZING_STORE}   = 'Zing::Store::Hash';
+  $ENV{ZING_ENCODER} = 'Zing::Encoder::Dump';
+  $ENV{ZING_TARGET}  = 'global';
 }
 
 use Zing::Daemon;
@@ -20,42 +13,35 @@ use Zing::Fork;
 use Zing::Logic;
 use Zing::Loop;
 use Zing::Process;
-use Zing::Redis;
 use Zing::Timer;
 
 use Data::Object::Space;
 
 our $PIDS = $$ + 1;
 
-# Zing/Daemon
+# Zing::Daemon
 {
   my $space = Data::Object::Space->new(
-    'Zing/Daemon'
+    'Zing::Daemon'
   );
   $space->inject(fork => sub {
     $ENV{ZING_TEST_FORK} || $PIDS++;
   });
-  my $_execute = $space->cop(
-    'execute'
+  my $_start = $space->cop(
+    'start'
   );
-  $space->inject(execute => sub {
-    my ($self, @args) = @_;
-    my $result = $_execute->($self, @args);
-    unlink $self->pid_path;
-    $result
-  });
   $space->inject(start => sub {
     my ($self, @args) = @_;
-    my $result = $self->execute(@args);
-    unlink $self->pid_path;
+    my $result = $_start->($self, @args);
+    unlink $self->cartridge->pidfile;
     $result
   });
 }
 
-# Zing/Fork
+# Zing::Fork
 {
   my $space = Data::Object::Space->new(
-    'Zing/Fork'
+    'Zing::Fork'
   );
   $space->inject(_waitpid => sub {
     $ENV{ZING_TEST_WAIT_ONE}
@@ -68,18 +54,18 @@ our $PIDS = $$ + 1;
     $self->space->load;
     my $process = $self->processes->{$pid} = $self->space->build(
       @{$self->scheme->[1]},
-      node => Zing::Node->new(pid => $pid),
       parent => $self->parent,
+      pid => $pid,
     );
     $process->execute;
     $process
   });
 }
 
-# Zing/Loop
+# Zing::Loop
 {
   my $space = Data::Object::Space->new(
-    'Zing/Loop'
+    'Zing::Loop'
   );
   $space->inject(execute => sub {
     my ($self, @args) = @_;
@@ -87,39 +73,20 @@ our $PIDS = $$ + 1;
   });
 }
 
-# Zing/Process
+# Zing::Process
 {
   my $space = Data::Object::Space->new(
-    'Zing/Process'
+    'Zing::Process'
   );
   $space->inject(_kill => sub {
     $ENV{ZING_TEST_KILL} || 0;
   });
 }
 
-# Zing/Redis
+# Zing::Timer
 {
   my $space = Data::Object::Space->new(
-    'Zing/Redis'
-  );
-  my $other = Data::Object::Space->new(
-    'Test/Zing/Store'
-  );
-  unless ($ENV{TEST_REDIS}) {
-    $space->load;
-    $other->load;
-    for my $routine (@{$other->routines}) {
-      next if $routine eq 'dump';
-      next if $routine eq 'load';
-      $space->inject($routine, $other->package->can($routine));
-    }
-  }
-}
-
-# Zing/Timer
-{
-  my $space = Data::Object::Space->new(
-    'Zing/Timer'
+    'Zing::Timer'
   );
   $space->inject(_time => sub {
     $ENV{ZING_TEST_TIME} || time;
